@@ -370,7 +370,7 @@ Zenoss::API::Router::Events - A JSON/ExtDirect interface to operations on events
     );
 
     # Replace SOMEMETHOD() with one of the available methods provided by this package
-    my $response = $api->zenoss->zenpack_SOMEMETHOD({parameter1 => 'value', parameter2 => 'value'});
+    my $response = $api->zenpack_SOMEMETHOD({parameter1 => 'value', parameter2 => 'value'});
 
 =head1 DESCRIPTION
 
